@@ -5,6 +5,7 @@ class ExerbTestCase < Test::Unit::TestCase
 
   def make(basename, kcode = 'none', internal_name = basename)
     internal_name = basename + '.rb' if internal_name == basename
+
     File.open(basename + '.rbc', 'w') { |file|
       file.puts "kcode	#{kcode}"
       file.puts "script	#{internal_name}	#{basename}.rb"
@@ -12,10 +13,8 @@ class ExerbTestCase < Test::Unit::TestCase
 
     File.open(basename + '.mak', 'w') { |file|
       file.puts "all: #{basename}.exe"
-      file.puts "#{basename}.exe: #{basename}.rba"
-      file.puts "	ruby ../bin/join.rb ../project/ruby167c/debug/ruby167c.exe #{basename}.rba #{basename}.exe"
-      file.puts "#{basename}.rba: #{basename}.rb #{basename}.rbc"
-      file.puts "	ruby ../bin/archive.rb #{basename}.rbc #{basename}.rba"
+      file.puts "#{basename}.exe: #{basename}.rbc"
+      file.puts "	ruby ../bin/exerb.rb -C ../project/ruby167c/release/ruby167c.exe #{basename}.rbc"
     }
 
     `make -f #{basename}.mak`
